%%% script to obtain EEG regressors from a single channel %%%

channel_num = 6;   % channel number, 1 to 28
fs = 128; % EEG sampling rate (Hz)
TR = 2.08; % fMRI TR


%%%%% first filter frequencies %%%%

delta=getFreqBand(eeg(:,channel_num) ,fs,1,4,'bp');
theta=getFreqBand(eeg(:,channel_num) ,fs,4,8,'bp');
alpha=getFreqBand(eeg(:,channel_num) ,fs,8,12,'bp');
beta=getFreqBand(eeg(:,channel_num) ,fs,12,30,'bp');

%%%% hilbert transform to get the envelopes %%%%


env_delta = abs(hilbert(delta));
env_theta = abs(hilbert(theta));
env_alpha = abs(hilbert(alpha));
env_beta = abs(hilbert(beta));


%%%% downsample to fMRI resolution, average over each TR %%%%

for t = 1:200
    alpha_regressor(t) = mean( env_alpha(  floor((t*TR*fs)):floor(((t+1)*TR*fs) )) );
    delta_regressor(t) = mean( env_delta(  floor((t*TR*fs)):floor(((t+1)*TR*fs) ) ));
    theta_regressor(t) = mean( env_theta(  floor((t*TR*fs)):floor(((t+1)*TR*fs) ) ));
    beta_regressor(t) = mean( env_beta(  floor((t*TR*fs)):floor(((t+1)*TR*fs) ) ));
end

%%%% convolve with the corresponding HRF function %%%%%%%%%%%%
% 
% alpha_regressor = conv(zscore(alpha_regressor), spm_hrf(TR) ); alpha_regressor = alpha_regressor(1:200);
% delta_regressor = conv(zscore(delta_regressor), spm_hrf(TR) ); delta_regressor = delta_regressor(1:200);
% theta_regressor = conv(zscore(theta_regressor), spm_hrf(TR) ); theta_regressor = theta_regressor(1:200);
% beta_regressor = conv(zscore(beta_regressor), spm_hrf(TR) ); beta_regressor = beta_regressor(1:200);


%%% construct regressors and save %%%%

eeg_regressors(:,1) = alpha_regressor';
%eeg_regressors(:,2) = beta_regressor';
%eeg_regressors(:,3) = theta_regressor';
%eeg_regressors(:,4) = delta_regressor';

%%% add noise regressors %%%%%

load_file = 'data/single_subj/noise_regressors.mat';
load(load_file);

dim = size(rp_save);

eeg_regressors(:, 2:1+dim(2) ) = rp_save;

save_file = 'data/single_subj/eeg_regressors.txt';
save(save_file,'eeg_regressors','-ascii');

















